@@ -1,5 +1,5 @@
 package Acme::Gosub;
-$Acme::Gosub::VERSION = '0.1.7';
+$Acme::Gosub::VERSION = '0.1.8';
 use strict;
 use warnings;
 use Carp;
@@ -156,7 +156,7 @@ Acme::Gosub - Implement BASIC-like "gosub" and "greturn" in Perl
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 SYNOPSIS
 
@@ -190,10 +190,6 @@ a BASIC programmer you can think of it as a poor man's recursion.
 
 For more information consult the examples in the test files.
 
-=head1 VERSION
-
-version 0.1.7
-
 =head1 FUNCTIONS
 
 =head2 filter()
@@ -254,7 +250,7 @@ Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Shlomi Fish.
+This software is copyright (c) 2019 by Shlomi Fish.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -262,7 +258,7 @@ the same terms as the Perl 5 programming language system itself.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/acme-gosub/issues>
+L<https://github.com/shlomif/perl-acme-gosub/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -371,8 +367,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/acme-gosub>
+L<https://github.com/shlomif/perl-acme-gosub>
 
-  git clone https://bitbucket.org/shlomif/perl-acme-gosub
+  git clone git://github.com/shlomif/perl-acme-gosub.git
 
 =cut
